==> haskell-hls-stylish-haskell-plugin-1.0.1.2-162-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-stylish-haskell-plugin
version:              1.0.1.2
visibility:           public
id:                   hls-stylish-haskell-plugin-1.0.1.2-IYnDvqTC6PI43fPqyrfix9
key:                  hls-stylish-haskell-plugin-1.0.1.2-IYnDvqTC6PI43fPqyrfix9
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0659aa4ed370c7416f852320154a40a6
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-stylish-haskell-plugin-1.0.1.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-stylish-haskell-plugin-1.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-1.0.1.2-IYnDvqTC6PI43fPqyrfix9
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2 ghc-9.2.8
    ghc-boot-th-9.2.8 ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lsp-types-1.6.0.0-2bofF1fRSsb5ddfkj3rDHp
    stylish-haskell-0.14.3.0-HVdObhHw2hU9MWOEqrptw2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-1.0.1.3-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-stylish-haskell-plugin
version:              1.0.1.3
visibility:           public
id:                   hls-stylish-haskell-plugin-1.0.1.3-CglKtVCOf5kHo2ub0JxGaK
key:                  hls-stylish-haskell-plugin-1.0.1.3-CglKtVCOf5kHo2ub0JxGaK
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e1cebd2993027dc1a2f8c3dd6ccd4452
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-stylish-haskell-plugin-1.0.1.3

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-stylish-haskell-plugin-1.0.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-1.0.1.3-CglKtVCOf5kHo2ub0JxGaK
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2 ghc-9.2.8
    ghc-boot-th-9.2.8 ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb
    stylish-haskell-0.14.3.0-FwGitWkEveR5gLjjhn52Qh text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
